<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit();
}

/**
 * Helper class.
 *
 * @since      2.1.0
 *
 * @package    Honeypot_Wp_Comment
 * @subpackage Honeypot_Wp_Comment/includes
 * @author     Prasidhda <pranuk.prwnsi@gmail.com>
 */
class Honeypot_Wp_Comment_Helper {
	/**
	 * Function to get the most common spam words
	 * https://gist.github.com/prasidhda/13c9303be3cbc4228585a7f1a06040a3
	 *
	 * @return array
	 *
	 * @since  2.1.0
	 * @access static
	 */
	public static function get_spam_words() {
		return apply_filters( 'honeypot_spam_words',
			array(
				"0%",
				"0% risk",
				"777",
				"99%",
				"99.9%",
				"100%",
				"100% more",
				"#1",
				"$$$",
				"100% free",
				"100% satisfied",
				"4U",
				"50% off",
				"Accept credit cards",
				"Acceptance",
				"Access",
				"Access now",
				"Access for free",
				"Accordingly",
				"Act Now",
				"Act immediately",
				"Action",
				"Action required",
				"Ad",
				"Additional income",
				"Addresses on CD",
				"Affordable",
				"Affordable deal",
				"All natural",
				"All new",
				"Amazed",
				"Amazing",
				"Amazing offer",
				"Amazing stuff",
				"Apply here",
				"Apply now",
				"Apply Online",
				"As seen on",
				"At no cost",
				"Auto email removal",
				"Avoid",
				"Avoid bankruptcy",
				"Bargain",
				"Be amazed",
				"Be surprised",
				"Be your own boss",
				"Believe me",
				"Being a member",
				"Beneficiary",
				"Best bargain",
				"Best deal",
				"Best price",
				"Best offer",
				"Beverage",
				"Big bucks",
				"Bill 1618",
				"Billing",
				"Billing address",
				"Billionaire",
				"Billion",
				"Billion dollars",
				"Bonus",
				"Boss",
				"Brand new pager",
				"Bulk email",
				"Buy",
				"Buy now",
				"Buy direct",
				"Buying judgments",
				"Cable converter",
				"Call",
				"Call free",
				"Call me",
				"Call now",
				"Calling creditors",
				"Can’t live without",
				"Cancel",
				"Cancel at any time",
				"Cancel now",
				"Cancellation required",
				"Cannot be combined with any other offer",
				"Cards accepted",
				"Cash",
				"Cash out",
				"Cash bonus",
				"Cashcashcash",
				"Casino",
				"Celebrity",
				"Cell phone cancer scam",
				"Cents on the dollar",
				"Certified",
				"Chance",
				"Cheap",
				"Check",
				"Check or money order",
				"Claims",
				"Claim now",
				"Claim your discount",
				"Claims not to be selling anything",
				"Claims to be in accordance with some spam law",
				"Claims to be legal",
				"Clearance",
				"Click",
				"Click below",
				"Click here",
				"Click now",
				"Click to get",
				"Click to remove",
				"Collect",
				"Collect child support",
				"Compare",
				"Compare now",
				"Compare online",
				"Compare rates",
				"Compete for your business",
				"Confidentially on all orders",
				"Congratulations",
				"Consolidate debt and credit",
				"Consolidate your debt",
				"Copy accurately",
				"Copy DVDs",
				"Costs",
				"Credit",
				"Credit bureaus",
				"Credit card offers",
				"Cures",
				"Cures baldness",
				"Deal",
				"Dear",
				"Debt",
				"Diagnostics",
				"Dig up dirt on friends",
				"Direct email",
				"Direct marketing",
				"Discount",
				"Do it now",
				"Do it today",
				"Don’t delete",
				"Don’t hesitate",
				"Dormant",
				"Double your",
				"Double your cash",
				"Double your income",
				"Double your wealth",
				"Drastically reduced",
				"Earn",
				"Earn $",
				"Earn extra cash",
				"Earn money",
				"Earn monthly",
				"Earn from home",
				"Earn per month",
				"Earn per week",
				"Easy terms",
				"Eliminate bad credit",
				"Eliminate debt",
				"Email extractor",
				"Email harvest",
				"Email marketing",
				"Exclusive deal",
				"Expect to earn",
				"Expire",
				"Explode your business",
				"Extra",
				"Extra cash",
				"Extra income",
				"Extract email",
				"Free",
				"Fantastic",
				"Fantastic deal",
				"Fantastic offer",
				"Fast cash",
				"Fast Viagra delivery",
				"Financial freedom",
				"Financially independent",
				"For free",
				"For instant access",
				"For just",
				"For just $",
				"For Only",
				"For you",
				"Form",
				"Free",
				"Free access",
				"Free bonus",
				"Free cell phone",
				"Free consultation",
				"Free DVD",
				"Free gift",
				"Free grant money",
				"Free hosting",
				"Free info",
				"Free information",
				"Free installation",
				"Free instant",
				"Free investment",
				"Free iPhone",
				"Free leads",
				"Free Macbook",
				"Free membership",
				"Free money",
				"Free offer",
				"Free preview",
				"Free priority mail",
				"Free quote",
				"Free sample",
				"Free trial",
				"Free website",
				"Freedom",
				"Friend",
				"Full refund",
				"Get",
				"Get it now",
				"Get out of debt",
				"Get paid",
				"Get started now",
				"Gift certificate",
				"Give it away",
				"Giving away",
				"Great",
				"Great deal",
				"Great offer",
				"Guarantee",
				"Guaranteed",
				"Guaranteed deposit",
				"Guaranteed income",
				"Guaranteed payment",
				"Have you been turned down?",
				"Hello",
				"Here",
				"Hidden",
				"Hidden assets",
				"Hidden charges",
				"Hidden fees",
				"High score",
				"Home",
				"Home based",
				"Home employment",
				"Home based business",
				"Human growth hormone",
				"Huge discount",
				"Hurry up",
				"If only it were that easy",
				"Important information regarding",
				"Important notification",
				"In accordance with laws",
				"Income",
				"Income from home",
				"Increase sales",
				"Increase traffic",
				"Increase your chances",
				"Increase your sales",
				"Incredible deal",
				"Info you requested",
				"Information you requested",
				"Instant",
				"Instant earnings",
				"Instant income",
				"Insurance",
				"Internet market",
				"Internet marketing",
				"Investment",
				"Investment decision",
				"It’s effective",
				"Join millions",
				"Join millions of Americans",
				"Junk",
				"Laser printer",
				"Leave",
				"Legal",
				"Legal notice",
				"Life",
				"Life Insurance",
				"Lifetime",
				"Lifetime access",
				"Lifetime deal",
				"Limited amount",
				"Limited number",
				"Limited offer",
				"Limited supply",
				"Limited time",
				"Limited time offer",
				"Limited time only",
				"Loan",
				"Long distance phone offer",
				"Lose",
				"Lose weight",
				"Lose weight spam",
				"Lower interest rates",
				"Lower monthly payment",
				"Lower your mortgage rate",
				"Lowest insurance rates",
				"Lowest price",
				"Lowest rate",
				"Luxury",
				"Luxury car",
				"Mail in order form",
				"Maintained",
				"Make $",
				"Make money",
				"Marketing",
				"Marketing solutions",
				"Mass email",
				"Medicine",
				"Medium",
				"Meet girls",
				"Meet me",
				"Meet singles",
				"Meet women",
				"Member",
				"Member stuff",
				"Message contains",
				"Message contains disclaimer",
				"Million",
				"Millionaire",
				"Million dollars",
				"Miracle",
				"MLM",
				"Money",
				"Money back",
				"Money making",
				"Month trial offer",
				"More Internet Traffic",
				"Mortgage",
				"Mortgage rates",
				"Multi-level marketing",
				"Name brand",
				"Never",
				"Never before",
				"New customers only",
				"New domain extensions",
				"Nigerian",
				"No age restrictions",
				"No catch",
				"No claim forms",
				"No cost",
				"No credit check",
				"No deposit required",
				"No disappointment",
				"No experience",
				"No fees",
				"No gimmick",
				"No hidden",
				"No hidden сosts",
				"No hidden fees",
				"No interests",
				"No inventory",
				"No investment",
				"No investment required",
				"No medical exams",
				"No middleman",
				"No obligation",
				"No payment required",
				"No purchase necessary",
				"No questions asked",
				"No selling",
				"No strings attached",
				"No-obligation",
				"Not intended",
				"Not junk",
				"Not scam",
				"Not spam",
				"Now",
				"Now only",
				"Number 1",
				"Number one",
				"Obligation",
				"Offshore",
				"Offer",
				"Offer expires",
				"Once in lifetime",
				"Once in a lifetime",
				"One hundred percent free",
				"One hundred percent guaranteed",
				"One time",
				"One time mailing",
				"Online biz opportunity",
				"Online degree",
				"Online job",
				"Online income",
				"Online marketing",
				"Online pharmacy",
				"Only",
				"Only $",
				"Open Opportunity",
				"Opt in",
				"Order",
				"Order now",
				"Order shipped by",
				"Order status",
				"Order today",
				"Outstanding values",
				"Passwords",
				"Pennies a day",
				"Per day",
				"Per month",
				"Per week",
				"Performance",
				"Phone",
				"Please read",
				"Potential earnings",
				"Pre-approved",
				"Presently",
				"Price",
				"Price protection",
				"Print form signature",
				"Print out and fax",
				"Priority mail",
				"Prize",
				"Problem",
				"Produced and sent out",
				"Profits",
				"Promise",
				"Promise you",
				"Purchase",
				"Pure profits",
				"Quote",
				"Rates",
				"Real thing",
				"Refinance",
				"Refinance home",
				"Refund",
				"Removal",
				"Removal instructions",
				"Remove",
				"Removes wrinkles",
				"Request",
				"Request now",
				"Request today",
				"Requires initial investment",
				"Reserves the right",
				"Reverses",
				"Reverses aging",
				"Risk free",
				"Risk-free",
				"Rolex",
				"Round the world",
				"Safeguard notice",
				"Sale",
				"Sample",
				"Satisfaction",
				"Satisfaction guaranteed",
				"Save $",
				"Save money",
				"Save now",
				"Save big money",
				"Save up to",
				"Score",
				"Score with babes",
				"Search engine listings",
				"Search engines",
				"Section 301",
				"See for yourself",
				"Sent in compliance",
				"Serious",
				"Serious cash",
				"Serious only",
				"Serious offer",
				"Shopper",
				"Shopping spree",
				"Sign up free today",
				"Social security number",
				"Solution",
				"Spam",
				"Special deal",
				"Special discount",
				"Special for you",
				"Special offer",
				"Special promotion",
				"Stainless steel",
				"Stock alert",
				"Stock disclaimer statement",
				"Stock pick",
				"Stop",
				"Stop calling me",
				"Stop emailing me",
				"Stop snoring",
				"Strong buy",
				"Stuff on sale",
				"Subject to cash",
				"Subject to credit",
				"Subscribe",
				"Subscribe now",
				"Subscribe for free",
				"Success",
				"Supplies",
				"Supplies are limited",
				"Take action",
				"Take action now",
				"Talks about hidden charges",
				"Talks about prizes",
				"Teen",
				"Tells you it’s an ad",
				"Terms",
				"Terms and conditions",
				"The best rates",
				"The following form",
				"They keep your money — no refund!",
				"They’re just giving it away",
				"This isn’t a scam",
				"This isn’t junk",
				"This isn’t spam",
				"This won’t last",
				"Thousands",
				"Time limited",
				"Traffic",
				"Trial",
				"Undisclosed recipient",
				"University diplomas",
				"Unlimited",
				"Unsecured credit",
				"Unsecured debt",
				"Unsolicited",
				"Unsubscribe",
				"Urgent",
				"US dollars",
				"Vacation",
				"Vacation offers",
				"Valium",
				"Viagra",
				"Vicodin",
				"VIP",
				"Visit our website",
				"Wants credit card",
				"Warranty",
				"Warranty expired",
				"We hate spam",
				"We honor all",
				"Web traffic",
				"Website visitors",
				"Weekend getaway",
				"Weight",
				"Weight loss",
				"What are you waiting for?",
				"What’s keeping you?",
				"While available",
				"While in stock",
				"While supplies last",
				"While you sleep",
				"Who really wins?",
				"Why pay more?",
				"Wife",
				"Will not believe your eyes",
				"Win",
				"Winner",
				"Winning",
				"Won",
				"Work from home",
				"Xanax",
				"You are a winner!",
				"You have been chosen",
				"You have been selected",
				"Your chance",
				"Your income",
				"Your status",
				"Zero chance",
				"Zero percent",
				"Zero risk",
			)
		);
	}

	/**
	 * Function to get the IP address
	 *
	 * @return string
	 * @since 2.3.0
	 * @access static
	 *
	 */
	public static function get_ip_address() {
		if ( isset( $_SERVER['HTTP_X_REAL_IP'] ) ) {
			return sanitize_text_field( wp_unslash( $_SERVER['HTTP_X_REAL_IP'] ) );
		} elseif ( isset( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
			// Proxy servers can send through this header like this: X-Forwarded-For: client1, proxy1, proxy2
			// Make sure we always only send through the first IP in the list which should always be the client IP.
			return (string) rest_is_ip_address( trim( current( preg_split( '/,/', sanitize_text_field( wp_unslash( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) ) ) ) );
		} elseif ( isset( $_SERVER['REMOTE_ADDR'] ) ) {
			return sanitize_text_field( wp_unslash( $_SERVER['REMOTE_ADDR'] ) );
		}

		return '';
	}
}